# useful_funcs
## _Useful functions for various applications_

## Installation
```sh
pip install useful_funcs
```

## Versions
Detailed descriptions of changes in various versions is given below
| Version | Date |
| ------ | ------ |
| 0.0.5 | 2024-03-31 |
| 0.0.4 | 2024-03-31 |
| 0.0.3 | 2024-01-22 |
| 0.0.2 | 2024-01-22 |
| 0.0.1 | 2024-01-22 |

## Version 0.0.5
- Updated README.md

## Version 0.0.4
- Added useful_colors
- Added useful_file_rename
- Added useful_interpol
- Added useful_isolated_points
- Added useful_stats_functions

## Version 0.0.3
- Added README.md

## Version 0.0.2
- Made basic improvements

## Version 0.0.1
- Added useful_calendar
- Added useful_closest
- Added useful_datetime


## Development

Want to contribute? Great!
Will be open to take suggestions soon.

